@@ -19,13 +19,14 @@ TIME_FORMAT = "%X"
 DAY_VIEW_FORMAT = "<b>%H:%M</b>"
 WEEK_VIEW_FORMAT = "<b>%a %d\n%H:%M</b>"
 MONTH_VIEW_FORMAT = "<b>%a %d\n%H:%M</b>"
+DB_FORMAT = '%Y-%m-%d %H:%M'
 FIRST_DAY_WEEK = 0
 DAY_START_HOUR = 8
 DAY_START_MINUTE = 0
 DAY_END_HOUR = 18
 DAY_END_MINUTE = 0
 
-VERSION = '0.2.6'
+VERSION = '0.2.7'
 
 try:
         import pygtk
@@ -202,7 +203,7 @@ class _Thread(threading.Thread, _IdleObject):
             if prefs[0]=='password':
               cal_client.password = prefs[1]
             if prefs[0]=='last_update':
-              last_update = datetime.datetime.strptime(prefs[1],'%Y-%m-%d %H:%M')
+              last_update = datetime.datetime.strptime(prefs[1],DB_FORMAT)
           future_update = datetime.datetime.now()  
           cal_client.source = 'mCalendar ' + VERSION
           cal_client.ProgrammaticLogin()  
@@ -225,7 +226,7 @@ class _Thread(threading.Thread, _IdleObject):
           self.emit("progress", 20)
 
           #send local update
-          self.dbcur.execute('SELECT uuid FROM events WHERE googleid!="" AND lastup>"'+last_update.strftime('%Y-%m-%d %H:%M')+'"')       
+          self.dbcur.execute('SELECT uuid FROM events WHERE googleid!="" AND lastup>"'+last_update.strftime(DB_FORMAT)+'"')       
           for an_event in self.dbcur.fetchall():
             e = Event(an_event[0],self)
             debug('uuid to update on google : %s' % (an_event[0]))
@@ -449,7 +450,7 @@ class _Thread(threading.Thread, _IdleObject):
 
           self.emit("progress", 90)
 
-          self.dbcur.execute('UPDATE prefs SET content="'+future_update.strftime("%Y-%m-%d %H:%M")+'" WHERE id ="last_update";')
+          self.dbcur.execute('UPDATE prefs SET content="'+future_update.strftime(DB_FORMAT)+'" WHERE id ="last_update";')
           self.db.commit()
 
           self.emit("progress", 100)
@@ -568,8 +569,8 @@ class Event:
               self.uuid = uuid.uuid4().__str__()
               self.new = True
               if start<>"":
-                self.start_datetime = datetime.datetime.strptime(start,'%Y-%m-%d %H:%M')
-                self.end_datetime = datetime.datetime.strptime(end,'%Y-%m-%d %H:%M')
+                self.start_datetime = datetime.datetime.strptime(start,DB_FORMAT)
+                self.end_datetime = datetime.datetime.strptime(end,DB_FORMAT)
               debug("new uuid : " + self.uuid)
             else:
               self.uuid = suuid
@@ -581,13 +582,13 @@ class Event:
             debug("load")
             widget.dbcur.execute('SELECT  start, end, description, repeat, repeatvalue, until,googleid,lastup,frequency FROM events where uuid="'+suuid+'"')
             for event in widget.dbcur.fetchall():
-              self.start_datetime = datetime.datetime.strptime(event[0],'%Y-%m-%d %H:%M')
-              self.end_datetime = datetime.datetime.strptime(event[1],'%Y-%m-%d %H:%M')
+              self.start_datetime = datetime.datetime.strptime(event[0],DB_FORMAT)
+              self.end_datetime = datetime.datetime.strptime(event[1],DB_FORMAT)
               self.repeat = int(event[3])
-              self.repeat_until =  datetime.datetime.strptime(event[5],'%Y-%m-%d %H:%M')
+              self.repeat_until =  datetime.datetime.strptime(event[5],DB_FORMAT)
               self.repeat_number = int(event[4])
               self.description = event[2]
-              self.lastup = datetime.datetime.strptime(event[7],'%Y-%m-%d %H:%M')
+              self.lastup = datetime.datetime.strptime(event[7],DB_FORMAT)
               self.googleid = event[6]
               self.frequency = event[8]
 
@@ -597,11 +598,11 @@ class Event:
         def saveToDB(self,widget):
             debug("saveToDB")
             if self.new==True:
-              widget.dbcur.execute('INSERT INTO events (uuid , start, end, description, repeat, repeatvalue, until, lastup,googleid,frequency) VALUES(?,?,?,?,?,?,?,?,?,?);',[self.uuid,self.start_datetime.strftime("%Y-%m-%d %H:%M"),self.end_datetime.strftime("%Y-%m-%d %H:%M"),self.description, str(int(self.repeat)) , str(self.repeat_number), self.repeat_until.strftime("%Y-%m-%d %H:%M"),self.lastup.strftime("%Y-%m-%d %H:%M"),str(self.googleid),self.frequency])
+              widget.dbcur.execute('INSERT INTO events (uuid , start, end, description, repeat, repeatvalue, until, lastup,googleid,frequency) VALUES(?,?,?,?,?,?,?,?,?,?);',[self.uuid,self.start_datetime.strftime(DB_FORMAT),self.end_datetime.strftime(DB_FORMAT),self.description, str(int(self.repeat)) , str(self.repeat_number), self.repeat_until.strftime(DB_FORMAT),self.lastup.strftime(DB_FORMAT),str(self.googleid),self.frequency])
 #              debug('INSERT INTO events (uuid , start, end, description, repeat, repeatvalue, until, lastup,googleid,frequency) VALUES("'+self.uuid + '","' + self.start_datetime.strftime("%Y-%m-%d %H:%M")+ '","' + self.end_datetime.strftime("%Y-%m-%d %H:%M") + '","' +self.description+ '",' + str(int(self.repeat)) + ',' + str(self.repeat_number)+ ',"' + self.repeat_until.strftime("%Y-%m-%d %H:%M")+ '","'+self.lastup.strftime("%Y-%m-%d %H:%M")+'","'+str(self.googleid)+'","'+self.frequency+'");')
               widget.db.commit()
             else:
-              widget.dbcur.execute('UPDATE events SET start=?, end=?, description=?, repeat=?, repeatvalue=?, until=?, lastup=?,googleid=?,frequency=? WHERE uuid=?;',[self.start_datetime.strftime("%Y-%m-%d %H:%M"),self.end_datetime.strftime("%Y-%m-%d %H:%M"),self.description, str(int(self.repeat)) , str(self.repeat_number), self.repeat_until.strftime("%Y-%m-%d %H:%M"),self.lastup.strftime("%Y-%m-%d %H:%M"),str(self.googleid),self.frequency,self.uuid])
+              widget.dbcur.execute('UPDATE events SET start=?, end=?, description=?, repeat=?, repeatvalue=?, until=?, lastup=?,googleid=?,frequency=? WHERE uuid=?;',[self.start_datetime.strftime(DB_FORMAT),self.end_datetime.strftime(DB_FORMAT),self.description, str(int(self.repeat)) , str(self.repeat_number), self.repeat_until.strftime(DB_FORMAT),self.lastup.strftime(DB_FORMAT),str(self.googleid),self.frequency,self.uuid])
               widget.db.commit()
 
         def delFromDB(self,widget):
@@ -1294,14 +1295,14 @@ class mCalendar:
               repeat = event[4]
               repeatvalue = int(event[5])
               frequency = event[6]
-              until = datetime.datetime.strptime(event[7],'%Y-%m-%d %H:%M')
-              start_datetime = datetime.datetime.strptime(event[0],'%Y-%m-%d %H:%M')
-              end_datetime = datetime.datetime.strptime(event[1],'%Y-%m-%d %H:%M')
+              until = datetime.datetime.strptime(event[7],DB_FORMAT)
+              start_datetime = datetime.datetime.strptime(event[0],DB_FORMAT)
+              end_datetime = datetime.datetime.strptime(event[1],DB_FORMAT)
               if self.current_view==0:
                 self.data.store.append((start_datetime.strftime(DAY_VIEW_FORMAT)+'\n'+end_datetime.strftime(DAY_VIEW_FORMAT),'',event[2],event[3],"",""))                
               elif self.current_view==1:
                 if not repeat:
-                  self.data.store.append((start_datetime.strftime(WEEK_VIEW_FORMAT),end_datetime.strftime(''),event[2],event[3]),"","")
+                  self.data.store.append((start_datetime.strftime(WEEK_VIEW_FORMAT),'',event[2],event[3],"",""))
                 else:
                   if frequency=="Day(s)":
                     diff = datetime.timedelta(days=repeatvalue)
@@ -1309,7 +1310,7 @@ class mCalendar:
                     d = start_datetime
                     while (d <= until) and (d <= getWeekDetails(self.view_datetime)[1]):
                       if d.strftime("%W")==self.view_datetime.strftime("%W"):
-                        self.data.store.append((d.strftime(WEEK_VIEW_FORMAT),end_datetime.strftime(''),event[2],event[3]))
+                        self.data.store.append((d.strftime(WEEK_VIEW_FORMAT),'',event[2],event[3]))
                       d = d+diff       
                       debug(d) 
                   elif frequency=="Week(s)":
@@ -1317,7 +1318,7 @@ class mCalendar:
                     d = start_datetime
                     while (d <= until) and (d <= getWeekDetails(self.view_datetime)[1]):
                       if d.strftime("%W")==self.view_datetime.strftime("%W"):
-                        self.data.store.append((d.strftime(WEEK_VIEW_FORMAT),end_datetime.strftime(''),event[2],event[3],"",""))
+                        self.data.store.append((d.strftime(WEEK_VIEW_FORMAT),'',event[2],event[3],"",""))
                       d = d+diff
                   elif frequency=="Month(s)":
                     d = start_datetime
@@ -1376,7 +1377,7 @@ class mCalendar:
                   freetime_end = start_datetime
 
               if freetime_end > startDay(self.view_datetime):
-                self.data.store.append((startDay(self.view_datetime).strftime(DAY_VIEW_FORMAT)+'\n'+freetime_end.strftime(DAY_VIEW_FORMAT),'','Free Time','',startDay(self.view_datetime).strftime('%Y-%m-%d %H:%M'),freetime_end.strftime('%Y-%m-%d %H:%M')))
+                self.data.store.append((startDay(self.view_datetime).strftime(DAY_VIEW_FORMAT)+'\n'+freetime_end.strftime(DAY_VIEW_FORMAT),'','Free Time','',startDay(self.view_datetime).strftime(DB_FORMAT),freetime_end.strftime(DB_FORMAT)))
 
               first = True
               for start_datetime,end_datetime in notfreetime:
@@ -1385,14 +1386,14 @@ class mCalendar:
 #                  print freetime_start
 #                  print freetime_end
                   if freetime_end > freetime_start:
-                    self.data.store.append((freetime_start.strftime(DAY_VIEW_FORMAT)+'\n'+freetime_end.strftime(DAY_VIEW_FORMAT),'','Free Time','',freetime_start.strftime('%Y-%m-%d %H:%M'),freetime_end.strftime('%Y-%m-%d %H:%M')))
+                    self.data.store.append((freetime_start.strftime(DAY_VIEW_FORMAT)+'\n'+freetime_end.strftime(DAY_VIEW_FORMAT),'','Free Time','',freetime_start.strftime(DB_FORMAT),freetime_end.strftime(DB_FORMAT)))
                   freetime_start = end_datetime
                 else:
                   first = False
                   freetime_start = end_datetime
 
-              if freetime_start.strftime('%Y-%m-%d %H:%M') < endDay(self.view_datetime).strftime('%Y-%m-%d %H:%M') and (len(notfreetime)>0):
-                self.data.store.append((freetime_start.strftime(DAY_VIEW_FORMAT)+'\n'+ endDay(self.view_datetime).strftime(DAY_VIEW_FORMAT),'','Free Time','',freetime_start.strftime('%Y-%m-%d %H:%M'),endDay(self.view_datetime).strftime('%Y-%m-%d %H:%M')))
+              if freetime_start.strftime(DB_FORMAT) < endDay(self.view_datetime).strftime(DB_FORMAT) and (len(notfreetime)>0):
+                self.data.store.append((freetime_start.strftime(DAY_VIEW_FORMAT)+'\n'+ endDay(self.view_datetime).strftime(DAY_VIEW_FORMAT),'','Free Time','',freetime_start.strftime(DB_FORMAT),endDay(self.view_datetime).strftime(DB_FORMAT)))
 
         def callPrefs(self,widget):
           mPrefs(self)
